<?php

namespace Database\Seeders;

use App\Models\User;
use App\Models\Admin;
use Illuminate\Support\Carbon;
use Illuminate\Database\Seeder;
use Spatie\Permission\Models\Role;
use Illuminate\Support\Facades\Hash;
use Spatie\Permission\Models\Permission;
use Illuminate\Database\Console\Seeds\WithoutModelEvents;

class UserRolePermissionSeeder extends Seeder
{
    /**
     * Run the database seeds.
     */
    public function run(): void
    {
         // Create Permissions
       Permission::create(['guard_name' => 'admin','name' => 'view role']);
       Permission::create(['guard_name' => 'admin','name' => 'create role']);
       Permission::create(['guard_name' => 'admin','name' => 'update role']);
       Permission::create(['guard_name' => 'admin','name' => 'delete role']);

       Permission::create(['guard_name' => 'admin','name' => 'view permission']);
       Permission::create(['guard_name' => 'admin','name' => 'create permission']);
       Permission::create(['guard_name' => 'admin','name' => 'update permission']);
       Permission::create(['guard_name' => 'admin','name' => 'delete permission']);

       Permission::create(['guard_name' => 'admin','name' => 'view user']);
       Permission::create(['guard_name' => 'admin','name' => 'create user']);
       Permission::create(['guard_name' => 'admin','name' => 'update user']);
       Permission::create(['guard_name' => 'admin','name' => 'delete user']);
       Permission::create(['guard_name' => 'admin','name' => 'view product']);
       Permission::create(['guard_name' => 'admin','name' => 'create product']);
       Permission::create(['guard_name' => 'admin','name' => 'update product']);
       Permission::create(['guard_name' => 'admin','name' => 'delete product']);
        // Create Roles
        $superAdminRole = Role::create(['guard_name' => 'admin','name' => 'super-admin']); //as super-admin
        $adminRole = Role::create(['guard_name' => 'admin','name' => 'admin']);

        // $staffRole = Role::create(['guard_name' => 'web','name' => 'staff']);
        $userRole = Role::create(['guard_name' => 'web','name' => 'طالب']);
        // $revRole = Role::create(['guard_name' => 'web','name' => 'محكم']);
        // $readerRole = Role::create(['guard_name' => 'web','name' => 'قارئ']);


        // Lets give all permission to super-admin role.
        $allPermissionNames = Permission::pluck('name')->toArray();
        $superAdminRole->givePermissionTo($allPermissionNames);

        // Let's give few permissions to admin role.
        $adminRole->givePermissionTo(['create role', 'view role', 'update role']);
        $adminRole->givePermissionTo(['create permission', 'view permission']);
        $adminRole->givePermissionTo(['create user', 'view user', 'update user']);
        $adminRole->givePermissionTo(['create product', 'view product', 'update product']);

      // Let's Create User and assign Role to it.

      $superAdminUser = Admin::firstOrCreate([
        'email' => 'superadmin@gmail.com',
        ], [
            'name' => 'Super Admin',
            'email' => 'superadmin@gmail.com',
            'password' => Hash::make ('111'),
            'state_id' => 1,
        ]);

        $superAdminUser->assignRole($superAdminRole);

        $adminUser = Admin::firstOrCreate([
            'email' => 'admin@gmail.com'
        ], [
            'name' => 'Admin',
            'email' => 'admin@gmail.com',
            'password' => Hash::make ('12345678'),
            'state_id' => 1,
        ]);

        $adminUser->assignRole($adminRole);

        // $revUser = User::firstOrCreate([
        //     'email' => 'rev@gmail.com',
        // ], [
        //     'name' => 'reviewer',
        //     'mobile'=>'0933633271',
        //     'city_id'=>1,
        //     'country_id'=>1,
        //     'email' => 'rev@gmail.com',
        //     'password' => Hash::make('111'),
        //     'state_id' => 1,
        //     'work' => 'eng',
        //     'specialty_general' => 'eng',
        //     'specialty_precise' => 'eng',
        //     'created_at'=>Carbon::now()
        // ]);

        // $revUser->assignRole($revRole);

        $readerUser = User::firstOrCreate([
            'email' => 'user@gmail.com',
        ], [
            'name' => 'user',
            // 'mobile'=>'0922556688',
            // 'city_id'=>1,
            // 'country_id'=>1,
            'email' => 'user@gmail.com',
            'password' => Hash::make('111'),
            'gender_id'=>1,
            'sclass_id'=>2,
            'status' => 'active',
            'created_at'=>Carbon::now()
        ]);

        $readerUser->assignRole($userRole);

    }
}
